==> enhanced-cnab-0.0.17.tar.gz: enhanced-cnab-0.0.17/cnab/core/especie/banks.py <==
CAIXA = {
    "CH": 1,
    "DM": 2,
    "DMI": 3,
    "DS": 4,
    "DSI": 5,
    "DR": 6,
    "LC": 7,
    "NCC": 8,
    "NCE": 9,
    "NCI": 10,
    "NCR": 11,
    "NP": 12,
    "NPR": 13,
    "TM": 14,
    "TS": 15,
    "NS": 16,
    "RC": 17,
    "FAT": 18,
    "ND": 19,
}

BANCO_BRASIL = { **CAIXA }

BRADESCO = {
    "DM": 1,
    "NP": 2,
    "NS": 3,
    "RC": 5,
    "DR": 6,
    "LC": 8,
    "WRT": 9,
    "CH": 10,
    "DS": 12,
    "ND": 13,
    "TM": 14,
    "TS": 15,
    "FAT": 18,
    "AP": 20,
    "ME": 21,
    "DIV": 99,
}

ITAU = {
    "DM": 1,
    "NP": 2,
    "NS": 3,
    "ME": 4,
    "RC": 5,
    "CT": 6,
    "CS": 7,
    "DS": 8,
    "LC": 9,
    "ND": 13,
    "DV": 15,
    "EC": 16,
    "CPS": 17,
    "DBP": 18,
    "DIV": 99,
}

SICOOB = {
    "DM": 1,
    "NP": 2,
    "NS": 3,
    "RC": 5,
    "DR": 6,
    "LC": 8,
    "WRT": 9,
    "CH": 10,
    "DS": 12,
    "ND": 13,
    "TM": 14,
    "TS": 15,
    "FAT": 18,
    "AP": 20,
    "ME": 21,
    "DIV": 99,
}

SICREDI = {
    "DMI": 'A',
    "DR": 'B',
    "NP": 'C',
    "NPR": 'D',
    "NS": 'E',
    "RC": 'G',
    "LC": 'H',
    "ND": 'I',
    "TS": 'J',
    "DIV": 'K',
}

SANTANDER = {
    "DM": 1,
    "NP": 2,
    "NS": 3,
    "RC": 5,
    "DR": 6,
    "LC": 8,
    "WRT": 9,
    "CH": 10,
    "DS": 12,
    "ND": 13,
    "TM": 14,
    "TS": 15,
    "FAT": 18,
    "AP": 20,
    "ME": 21,
    "DIV": 99,
}

ABC = {
    "CH": 1,
    "DM": 2,
    "DMI": 3,
    "DS": 4,
    "DSI": 5,
    "DR": 6,
    "LC": 7,
    "NCC": 8,
    "NCE": 9,
    "NCI": 10,
    "NCR": 11,
    "NP": 12,
    "NPR": 13,
    "TM": 14,
    "TS": 15,
    "NS": 16,
    "RC": 17,
    "FAT": 18,
    "ND": 19,
}

BV = {
    "CH": 1,
    "DM": 2,
    "DS": 4,
    'CC': 31,
}

BANKS = {
    '104': CAIXA,
    '341': ITAU,
    '001': BANCO_BRASIL,
    '237': BRADESCO,
    '756': SICOOB,
    '748': SICREDI,
    '033': SANTANDER,
    '084': BRADESCO,
    '246': ABC,
    '655': BV,
}

==> enhanced-cnab-0.0.19.tar.gz: enhanced-cnab-0.0.19/cnab/core/especie/banks.py <==
CAIXA = {
    "CH": 1,
    "DM": 2,
    "DMI": 3,
    "DS": 4,
    "DSI": 5,
    "DR": 6,
    "LC": 7,
    "NCC": 8,
    "NCE": 9,
    "NCI": 10,
    "NCR": 11,
    "NP": 12,
    "NPR": 13,
    "TM": 14,
    "TS": 15,
    "NS": 16,
    "RC": 17,
    "FAT": 18,
    "ND": 19,
}

BANCO_BRASIL = {**CAIXA}

BRADESCO = {
    "DM": 1,
    "NP": 2,
    "NS": 3,
    "RC": 5,
    "DR": 6,
    "LC": 8,
    "WRT": 9,
    "CH": 10,
    "DS": 12,
    "ND": 13,
    "TM": 14,
    "TS": 15,
    "FAT": 18,
    "AP": 20,
    "ME": 21,
    "DIV": 99,
}

ITAU = {
    "DM": 1,
    "NP": 2,
    "NS": 3,
    "ME": 4,
    "RC": 5,
    "CT": 6,
    "CS": 7,
    "DS": 8,
    "LC": 9,
    "ND": 13,
    "DV": 15,
    "EC": 16,
    "CPS": 17,
    "DBP": 18,
    "DIV": 99,
}

SICOOB = {
    "DM": 1,
    "NP": 2,
    "NS": 3,
    "RC": 5,
    "DR": 6,
    "LC": 8,
    "WRT": 9,
    "CH": 10,
    "DS": 12,
    "ND": 13,
    "TM": 14,
    "TS": 15,
    "FAT": 18,
    "AP": 20,
    "ME": 21,
    "DIV": 99,
}

SICREDI = {
    "DMI": "A",
    "DR": "B",
    "NP": "C",
    "NPR": "D",
    "NS": "E",
    "RC": "G",
    "LC": "H",
    "ND": "I",
    "TS": "J",
    "DIV": "K",
}

SANTANDER = {
    "DM": 1,
    "NP": 2,
    "NS": 3,
    "RC": 5,
    "DR": 6,
    "LC": 8,
    "WRT": 9,
    "CH": 10,
    "DS": 12,
    "ND": 13,
    "TM": 14,
    "TS": 15,
    "FAT": 18,
    "AP": 20,
    "ME": 21,
    "DIV": 99,
}

ABC = {
    "CH": 1,
    "DM": 2,
    "DMI": 3,
    "DS": 4,
    "DSI": 5,
    "DR": 6,
    "LC": 7,
    "NCC": 8,
    "NCE": 9,
    "NCI": 10,
    "NCR": 11,
    "NP": 12,
    "NPR": 13,
    "TM": 14,
    "TS": 15,
    "NS": 16,
    "RC": 17,
    "FAT": 18,
    "ND": 19,
}

BV = {
    "CH": 1,
    "DM": 2,
    "DS": 4,
    "CC": 31,
}

BANKS = {
    "104": CAIXA,
    "341": ITAU,
    "001": BANCO_BRASIL,
    "237": BRADESCO,
    "756": SICOOB,
    "748": SICREDI,
    "033": SANTANDER,
    "084": BRADESCO,
    "246": ABC,
    "655": BV,
}
